==> iwrite-1.0.1.4.tar.gz: iwrite-1.0.1.4/src/item_image.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
*/
/*
Copyright (c) 2015-2016, iwrite authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __item_image_h__

#include "item_common.h"
#include "item_method.h"
#include "pixbuf.h"

struct item_image
{
  double                                m_pos_x;
  double                                m_pos_y;
  double                                m_len_x;
  double                                m_len_y;
  int                                   m_border;
  enum line_style_type                  m_border_style;
  double                                m_border_thickness;
  GdkRGBA                               m_border_color;
  int                                   m_overlay;
  GdkPixbuf *                           m_image;
  GdkPixbuf *                           m_image_sized;
};

extern void
item_image_assign(
  struct item_image*const               o_image,
  struct item_method*const              o_method);

extern void
item_image_get_bbox(
  struct geom_rect*const                o_bbox,
  int*const                             o_overlay,
  void const*const                      i_object);

extern void
item_image_in_event(
  enum event_type*const                 o_type,
  struct item_image const*const         i_image,
  struct item_in_event const*const      i_ctx);

extern void
item_image_destroy(
  struct item_image*const               io_image);

extern void
item_image_discharge(
  struct item_image*const               io_image);

extern void
item_image_draw(
  struct item_image*const               io_image,
  struct item_draw_context const*const  i_ctx);

extern int
item_image_load(
  GError**                              o_error,
  struct item_image*const               io_image,
  char const*                           i_filename);

extern void
item_image_move(
  struct item_image*const               io_image,
  struct geom_point const*const         i_event);

extern void
item_image_normalize(
  struct item_image*const               io_image,
  double const                          i_bound_width,
  double const                          i_bound_height);

extern int
item_image_property(
  struct item_image*const               io_image);

extern int
item_image_read(
  GError**                              o_error,
  struct item_image*const               io_image,
  struct bson_node *const               i_element);

extern void
item_image_resize(
  struct item_image*const               io_image,
  struct item_resize_event const*const  i_ctx);

extern int
item_image_write(
  GError**                              o_error,
  FILE*const                            io_fp,
  struct item_image const*const         io_image);

#define __item_image_h__
#endif

==> iwrite-2.0.1.0.tar.gz: iwrite-2.0.1.0/src/item_image.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
*/
/*
Copyright (c) 2015-2016, iwrite authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __item_image_h__

#include "item_common.h"
#include "item_method.h"
#include "pixbuf.h"

struct item_image
{
  gdouble                               m_pos_x;
  gdouble                               m_pos_y;
  gdouble                               m_len_x;
  gdouble                               m_len_y;
  struct item_border_attr               m_border;
  GdkPixbuf *                           m_image;
  GdkPixbuf *                           m_image_sized;
};

extern void
item_image_assign(
  struct item_image*const               o_image,
  struct item_method*const              o_method);

extern void
item_image_get_bbox(
  struct geom_rect*const                o_bbox,
  void const*const                      i_object);

extern void
item_image_in_event(
  enum event_type*const                 o_type,
  struct item_image const*const         i_image,
  struct item_in_event const*const      i_ctx);

extern void
item_image_destroy(
  struct item_image*const               io_image);

extern void
item_image_discharge(
  struct item_image*const               io_image);

extern void
item_image_draw(
  struct item_image*const               io_image,
  struct item_draw_context const*const  i_ctx);

extern int
item_image_load(
  GError**                              o_error,
  struct item_image*const               io_image,
  char const*                           i_filename);

extern void
item_image_move(
  struct item_image*const               io_image,
  struct geom_point const*const         i_event);

extern void
item_image_normalize(
  struct item_image*const               io_image,
  double const                          i_bound_width,
  double const                          i_bound_height);

extern int
item_image_property(
  struct item_image*const               io_image);

extern int
item_image_read(
  GError**                              o_error,
  struct item_image*const               io_image,
  struct xml *const               i_element);

extern void
item_image_resize(
  struct item_image*const               io_image,
  struct item_resize_event const*const  i_ctx);

extern int
item_image_write(
  GError**                              o_error,
  FILE*const                            io_fp,
  struct item_image const*const         io_image);

#define __item_image_h__
#endif
